# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	I/O on in-core objects like strings and arrays for Perl
Name:		perl-IO-stringy
Version:	2.113
Release:	1.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/IO-stringy
Source0:	https://cpan.metacpan.org/modules/by-module/IO/IO-Stringy-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(FileHandle)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(overload)
BuildRequires:	perl(parent)
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# New upstream maintainer for 2.112 finally got the dist name right
Provides:	perl-IO-Stringy = %{version}-%{release}

# Avoid doc-file dependency on /usr/bin/perl
%{?perl_default_filter}

%description
This toolkit primarily provides modules for performing both traditional
and object-oriented I/O) on things *other* than normal filehandles; in
particular, IO::Scalar, IO::ScalarArray, and IO::Lines.

In the more-traditional IO::Handle front, we have IO::AtomicFile, which
may be used to painlessly create files that are updated atomically.

And in the "this-may-prove-useful" corner, we have IO::Wrap, whose
exported wraphandle() function will clothe anything that's not a blessed
object in an IO::Handle-like wrapper... so you can just use OO syntax
and stop worrying about whether your function's caller handed you a
string, a globref, or a FileHandle.

%prep
%setup -q -n IO-Stringy-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%if 0%{?_licensedir:1}
%license COPYING LICENSE
%else
%doc COPYING LICENSE
%endif
%doc Changes examples/ README
%{perl_vendorlib}/IO/
%{_mandir}/man3/IO::AtomicFile.3*
%{_mandir}/man3/IO::InnerFile.3*
%{_mandir}/man3/IO::Lines.3*
%{_mandir}/man3/IO::Scalar.3*
%{_mandir}/man3/IO::ScalarArray.3*
%{_mandir}/man3/IO::Stringy.3*
%{_mandir}/man3/IO::Wrap.3*
%{_mandir}/man3/IO::WrapTie.3*

%changelog
* Fri Jan 17 2020 Paul Howarth <paul@city-fan.org> - 2.113-1
- Update to 2.113
  - Get rid of use of Common and TBone in all tests
  - Convert to Dist::Zilla for authoring
  - Cleaned up some of the docs (needs more)

* Sat Dec 14 2019 Paul Howarth <paul@city-fan.org> - 2.112-1
- Update to 2.112
  - Added the change log from any prior source that could be found, and
    formatted the log to fit metacpan.org loose standards
  - Change use vars qw() to our $whatever instead
  - Hide IO::WrapTie subclasses from PAUSE
  - Rebuild Makefile.PL to contain all of the prerequisites
  - Convert README to README.md
  - Fix the documentation in the main module, IO::Stringy to better indicate
    where to get info and how to use the module
  - Fix the dist's META information to indicate the original author and license
  - Add a LICENSE file
  - Add AppVeyor CI testing
  - Add Travis CI testing
  - Update t/IO_InnerFile.t to use Test::More and a proper TEMP file
    (CPAN RT#103895)

* Sat Jun  8 2019 Paul Howarth <paul@city-fan.org> - 2.111-13
- Perl 5.30 rebuild

* Sat Apr 28 2018 Paul Howarth <paul@city-fan.org> - 2.111-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Wed Aug 31 2016 Paul Howarth <paul@city-fan.org> - 2.111-5
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jun 15 2015 Paul Howarth <paul@city-fan.org> - 2.111-2
- Perl 5.22 rebuild

* Thu Apr 23 2015 Paul Howarth <paul@city-fan.org> - 2.111-1
- Update to 2.111
  - Update maintainer's name, which is now Dianne Skoll

* Mon Jan 26 2015 Paul Howarth <paul@city-fan.org> - 2.110-28
- Classify buildreqs by usage
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4
- Avoid doc-file dependency on /usr/bin/perl on recent distributions

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 2.110-19
- Perl 5.16 rebuild

* Fri Apr  6 2012 Paul Howarth <paul@city-fan.org> - 2.110-18
- Add buildreqs for Perl core modules that might be dual-lived
- Don't need to remove empty directories from buildroot
- Drop compatibility with old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 2.110-9
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 2.110-8
- Rebuild for perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 2.110-7
- Fix dist tag to work with RHEL6 Beta

* Fri Jan 15 2010 Paul Howarth <paul@city-fan.org> - 2.110-6
- Spec cleanup, sync with Rawhide (Merge Review #552564)
- Dist tag for Rawhide no longer needs special-casing

* Fri Sep 11 2009 Paul Howarth <paul@city-fan.org> - 2.110-5
- Define RPM macros in global scope

* Tue Nov  4 2008 Paul Howarth <paul@city-fan.org> - 2.110-4
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Sat Mar 17 2007 Paul Howarth <paul@city-fan.org> - 2.110-3
- Fix dist tag for development releases, CentOS, and Fedora 7 onwards
- Remove buildroot unconditionally in %%clean and %%install
- Remove %%{__perl_version} macro, used only once
- Remove %%{__perl_package} macro, used only twice
- Don't use macros in command paths, hardcode them instead
- Fix argument order for find with -depth
- Use search.cpan.org URLs
- Define %%{__id_u} in a more portable way
- Add buildreq perl(ExtUtils::MakeMaker)

* Thu Jul  7 2005 Paul Howarth <paul@city-fan.org> - 2.110-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Fri Feb 25 2005 Paul Howarth <paul@city-fan.org> - 2.110-1
- Update to 2.110
- Tidy up spec file
- Remove docs, add examples

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> - 2.109-2
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system; in such cases, just
  rebuild from the source RPM
- Changed distribution-identifying macros for greater portability

* Thu Mar 04 2004 Paul Howarth <paul@city-fan.org> - 2.109-1
- Update to 2.109

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> - 2.108-2
- Unified spec file for Red Hat and Fedora Core

* Fri Dec 12 2003 Paul Howarth <paul@city-fan.org> - 2.108-1.fc1
- Build for Fedora Core 1
- More macros
- Expanded description

* Tue Oct 15 2002 Paul Howarth <paul@city-fan.org> - 2.108-1
- Upgrade to 2.108
- Build for RHL 8.0

* Sun Aug 26 2001 Ramiro Morales <rmpms@usa.net>
- Build on RHL 6.2
- Buildarch noarch
- Include docs
- s/Copyright/License/

* Sun Aug 26 2001 root <root@redhat.com>
- Spec file was autogenerated
